@@ -246,7 +246,9 @@ def version():
     for package_name in CONCERNED_PACKAGES:
         try:
             _package = importlib.import_module(package_name)
-            click.echo("{}=={}".format(package_name, _package.__version__))
+            _version = getattr(_package, "__version__", None) or getattr(_package, "version", None)
+            if _version:
+                click.echo("{}=={}".format(package_name, _version))
         except:
             pass
 
@@ -311,6 +313,26 @@ def update_data(data_bundle_path, base, minbar, tick, with_derivatives, concurre
         click.echo("""请先使用'rqsdk install rqalpha_plus'安装rqalpha_plus""")
 
 
+@cli.command()
+@click.option(
+    '-d', '--data-bundle-path', default=DEFAULT_BUNDLE_PATH, type=click.Path(file_okay=False),
+    help="bundle 目录，默认为 {}".format(DEFAULT_BUNDLE_PATH)
+)
+@click.option('--minbar', help="检查分钟数据是否异常", default=False, is_flag=True)
+def check_data(data_bundle_path, minbar):
+    """
+        检查bundle中的数据是否正确
+    """
+    try:
+        from rqalpha_plus.bundle import check_min_bar_data
+        if not all([minbar]):
+            print("请选择品种:[--minbar]")
+        elif minbar:
+            check_min_bar_data(data_bundle_path)
+    except ImportError:
+        click.echo("""请先使用'rqsdk install rqalpha_plus'安装rqalpha_plus""")
+
+
 @cli.command()
 @click.option(
     '-d', '--data-bundle-path', default=DEFAULT_BUNDLE_PATH, type=click.Path(file_okay=False),
